# @api private
class logrotate::cron {
  assert_private()

  if $::logrotate::manage_cron {
    $cron_files = ['hourly', 'daily', 'weekly', 'monthly'].map |$frequency| {
      "/etc/cron.${frequency}/logrotate"
    }

    if versioncmp($facts['os']['release']['major'], '10') >= 0 {
      systemd::dropin_file { 'logrotate timer override':
        unit     => 'logrotate.timer',
        filename => 'override.conf',
        content  => epp('logrotate/override.conf', {frequency => $::logrotate::cron_frequency}),
      }
    }

    file {
      $cron_files.filter |$name| { $::logrotate::cron_frequency in $name }:
        ensure  => file,
        owner   => 'root',
        group   => 'root',
        mode    => '0755',
        content => epp('logrotate/logrotate.cron'),
      ;
      $cron_files.filter |$name| { !($::logrotate::cron_frequency in $name) }:
        ensure => absent,
      ;
    }
  }
}
